@@ -3,7 +3,7 @@
 # If you want to add a Browser to extend AWStats database detection capabilities,
 # you must add an entry in BrowsersSearchIDOrder and in BrowsersHashIDLib.
 #-------------------------------------------------------
-# $Revision: 1.33 $ - $Author: eldy $ - $Date: 2003/12/06 23:51:25 $
+# $Revision: 1.39 $ - $Author: eldy $ - $Date: 2005/01/15 14:12:39 $
 
 
 #package AWSUA;
@@ -16,7 +16,7 @@
 # Note: Regex IDs are in lower case and ' ' and '+' are changed into '_'
 #-------------------------------------------------------
 @BrowsersSearchIDOrder = (
-# Most frequent standard web browsers are first in this list
+# Most frequent standard web browsers are first in this list (except msie, netscape and firefox)
 'firebird',
 'go!zilla',
 'icab',
@@ -32,6 +32,7 @@
 'amigavoyager',
 'aweb',
 'bpftp',
+'camino',
 'chimera',
 'cyberdog',
 'dillo',
@@ -48,6 +49,7 @@
 'hotjava',
 'ibrowse',
 'intergo',
+'javaws',
 'k\-meleon',
 'linemodebrowser',
 'lotus\-notes',
@@ -127,7 +129,9 @@
 # Common web browsers text
 'msie','MS Internet Explorer',
 'netscape','Netscape',
-'firebird','Firebird',
+'firefox','Firefox',
+
+'firebird','Firebird (Old Firefox)',
 'go!zilla','Go!Zilla',
 'icab','iCab',
 'konqueror','Konqueror',
@@ -142,7 +146,8 @@
 'amigavoyager','AmigaVoyager',
 'aweb','AWeb',
 'bpftp','BPFTP',
-'chimera','Chimera',
+'camino','Camino',
+'chimera','Chimera (Old Camino)',
 'cyberdog','Cyberdog',
 'dillo','Dillo',
 'dreamcast','Dreamcast',
@@ -219,6 +224,7 @@
 'apt','Debian APT',
 'curl','Curl',
 'csscheck','WDG CSS Validator',
+'javaws','Java Web Start',
 'wget','Wget',
 'w3m','w3m',
 'w3c_css_validator','W3C CSS Validator',
@@ -252,6 +258,7 @@
 # Standard web browsers
 'msie','msie',
 'netscape','netscape',
+'firefox','firefox',
 
 'firebird','phoenix',
 'go!zilla','gozilla',
@@ -266,6 +273,7 @@
 'avantbrowser','avant',
 'aweb','aweb',
 'bpftp','bpftp',
+'camino','chimera',
 'chimera','chimera',
 'cyberdog','cyberdog',
 'dillo','dillo',
@@ -326,6 +334,7 @@
 'webtv','webtv',
 # Other kind of browsers
 'apt','apt',
+'javaws','javaws',
 'webzip','webzip',
 'staroffice','staroffice',
 'mozilla','mozilla'
@@ -335,36 +344,29 @@
 1;
 
 
-# TODO
-# Add Gecko category -> IE / Netscape / Gecko(except Netscape) / Other
-# IE (based on Mosaic)
-# Netscape family
-# Gecko except Netscape (Mozilla, Firebird (was Phoenix), Galeon, AmiZilla, Dino, and few others) 
-# Opera (Opera 6/7) 
-# KHTML (Konqueror, Safari) 
-
-
-# Browsers example
+# Browsers examples by engines
 #
+# -- Mosaic --
 # MSIE		4.0  	Mozilla/4.0 (compatible; MSIE 5.0; Windows 98; DigExt; KITV4 Wanadoo; KITV5 Wanadoo)
 #
+# -- Gecko Netscape --
 # Netscape	4.05	Mozilla/4.05 [fr]C-SYMPA (Win95; I)
 # Netscape	4.7     Mozilla/4.7 [fr] (Win95; I)
 # Netscape	6.0		Mozilla/5.0 (Macintosh; N; PPC; fr-FR; m18) Gecko/20001108 Netscape6/6.0
 # Netscape	7.02	Mozilla/5.0 (Platform; Security; OS-or-CPU; Localization; rv:1.0.2) Gecko/20030208 Netscape/7.02 
 #
+# -- Gecko others --
 # Mozilla	1.3		Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.3) Gecko/20030312
+# Firefox	0.9		Mozilla/5.0 (Windows; U; Windows NT 5.0; en-US; rv:1.5a) Gecko/20030728 Mozilla Firefox/0.9.1
+# Firebird,Phoenix,Galeon,AmiZilla,Dino
+# Autre             Mozilla/3.01 (compatible;)
 #
-# Firebird	0.6		Mozilla/5.0 (Windows; U; Windows NT 5.0; en-US; rv:1.5a) Gecko/20030728 Mozilla Firebird/0.6.1
-#
+# -- Opera --
 # Opera		6.03	Mozilla/3.0 (Windows 98; U) Opera 6.03  [en]
 # Opera		5.12    Mozilla/3.0 (Windows 98; U) Opera 5.12  [en]
 # Opera		3.21    Opera 3.21, Windows:
 #
-# Galeon
-#
+# -- KHTML --
 # Safari
-#
 # Konqueror
 #
-# Autre             Mozilla/3.01 (compatible;)
